Learn R Programming

bcrm (version 0.1)

plot.bcrm: Plot the estimated dose-toxicity curve

Description

The estimated dose-toxicity curve using the Bayesian continuous reassessment method is plotted for the patients thus far recruited into the trial

Usage

## S3 method for class 'bcrm':
plot(x, \ldots)

Arguments

x
An object of class "bcrm", as returned by bcrm
...
Further arguments passed to or from other methods

Details

The estimated 2.5%, 25%, 50%, 75%, 97.5% quantiles of the probability of toxicity are plotted for each dose. Additionally, a histogram of the number of toxicities and non-toxicities is plotted at each experimented dose.

See Also

bcrm