bcrm model.## S3 method for class 'bcrm':
print(x, \ldots)
## S3 method for class 'bcrm.sim':
print(x, \ldots)bcrmprint function currently produces summary information about the design used, the data observed, current posterior estimates of toxicity, and the next recommended dose level.
If a simulation study is conducted, then the following operating characteristics are printed:
[object Object],[object Object]bcrm