Usage
Posterior.exact(tox,notox,sdose,ff,prior.alpha)
Posterior.BRugs(tox,notox,sdose,ff,prior.alpha,burnin.itr,production.itr)
Posterior.R2WinBUGS(tox,notox,sdose,ff,prior.alpha,burnin.itr,production.itr
,bugs.directory)
Arguments
tox
A vector of length k listing the number of patients who have experienced the outcome (toxicity) at each dose level 1,...,k. If missing, then it is assumed that no data have thus far been collected.
notox
A vector of length k listing the number of patients who have not experienced the outcome (toxicity) at each dose level 1,...,k. If missing, then it is assumed that no data have thus far been collected.
sdose
A vector of length k listing the standardised doses used in the CRM model.
ff
A string indicating the functional form of the dose-response curve. Options are
[object Object],[object Object],[object Object],[object Object]
prior.alpha
A list of length 3 containing the distributional information for the prior. The first element is a number from 1-4 specifying the type of distribution. Options are
- Gamma(a,b), where a=shape, b=scale: mean=a*b, variance=a*b*b
- Uniform(a
burnin.itr
Number of burn-in iterations (default 2000).
production.itr
Number of production iterations (default 2000).
bugs.directory
Directory that contains the WinBUGS executable if method="R2WinBUGS". Defaults to "C:/Program Files/WinBUGS14/".